Identifies groups of SNPs that are mapped to the exact same genomic position on each chromosome. Returns a list where each element corresponds to one group of overlapping SNPs.
Identifies SNPs that share the same position on the same chromosome.
check.snp.same.position(snpmap)
check.snp.same.position(snpmap)A list of character vectors, each with names of SNPs found at the same position.
List of SNP groups sharing positions.
df <- data.frame(Chromosome = c(1, 1, 2),
Position = c(100, 100, 200),
Name = c("SNP1", "SNP2", "SNP3"))
check.snp.same.position(df)
#> Analyzing chromosome 1
#> Analyzing chromosome 2
#> [[1]]
#> [1] "SNP1" "SNP2"
#>