Imports genotype data from multiple configurations defined in an
SNPImportList object and combines them into a unified SNPDataLong object.
importAllGenos(object)
# S4 method for class 'SNPImportList'
importAllGenos(object)A combined SNPDataLong object.